# Sonotoria

Sonotoria is a library designed to provide helping features around jinja2 such as:
 - use jinja2 syntax as a reverse template to extract data from strings
 - read yaml config file with jinja2 variables inside


# To run tests

First make sure all deps are installed (it is advised to create a virtual environment) using the following command:
> pip install -r requirements.txt

Then you can run the following command:
> pytest -v && pylint sonotoria tests

# Contributors

 * Emmanuel Pluot (aka. Neomyte)
